@@ -5,8 +5,8 @@ from __future__ import absolute_import
 .. moduleauthor:: Alex Kessinger <alex@app.net>
 
 """
-__version__ = '0.3.6'
-__author__ = 'Alex Kessinger, Bryan Berg, App.net'
+__version__ = '0.3.7'
+__author__ = 'Alex Kessinger, Bryan Berg, Mark Thurman, App.net'
 __license__ = 'MIT'
 
 from .models import User, Post, Message, Interaction, Channel, App, Token, Place
